##
# Core Functions
These core functions are used by many different parts of the FDTDX package

::: fdtdx.core.WaveCharacter
A container for specifying the character of a wave by either frequency, period or wavelength. Additionally, a phase offset can be set.

# Physical metrics
::: fdtdx.core.metric_efficiency
Convenience function that computes the ratio between a physical metrics measured at different places in the simulation.

::: fdtdx.core.compute_energy
Computes the physical energy in the simualation grid.

::: fdtdx.core.poynting_flux
Computes the poynting flux.